/**
 * Copyright (c) 2013-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.extension.command.monitoring.so.components.framework.exception;

import org.ow2.petals.cli.extension.command.monitoring.so.api.SubscriptionObject;
import org.ow2.petals.cli.extension.command.monitoring.so.api.exception.SubscriptionObjectException;

/**
 * The Petals component with the given identifier does not exist.
 * 
 * @author Christophe Deneux - Linagora
 */
public class ComponentDoesNotExistException extends SubscriptionObjectException {

    private static final long serialVersionUID = 5090883034222601833L;

    private final static String ERROR_MSG_COMP_DOES_NOT_EXIST = "The component '%s' does not exist.";

    /**
     * The component identifier that does not exist
     */
    private final String componentIdentifier;

    public ComponentDoesNotExistException(final SubscriptionObject subscriptionObject,
            final String componentIdentifier) {
        super(subscriptionObject, String.format(ERROR_MSG_COMP_DOES_NOT_EXIST, componentIdentifier));
        this.componentIdentifier = componentIdentifier;
    }

    /**
     * @return The component identifier that does not exist
     */
    public String getComponentIdentifier() {
        return this.componentIdentifier;
    }

}
